# UESURIHelper - this class provides helper methods for working with UESURI.
#
# <tt><b>author</b></tt> uni429
#
# <tt><b>since</b></tt> UES6-00
class Ues::Core::Commons::Uri::UESURIHelper

  # <p>Invariable UESURI is such an UESURI that clearly and permanently identifies
  # one particular object. Such UESURI must have ID specified for territory and
  # for all UESURI parts which forms UESURI entity part (artifact and object when
  # there is an object part in the UESURI).</p>
  #
  # <p>When UESURI is invariable, the UESURI can be used as a key in cache or
  # Hash-like collections (e.g. HashMap).</p>
  #
  # <tt><b>param</b></tt> uri Tested UESURI.
  #
  # <tt><b>return</b></tt> True, when UESURI is invariable, otherwise false.
  #
  # <tt><b>since</b></tt> UES6-04
  def self.isInvariable(uri)
    uri1 = Java::cz.ues.core.commons.uri.UESURI.parseURI(uri.to_s)
    return Java::cz.ues.core.commons.uri.UESURIHelper.isInvariable(uri1)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias is_invariable isInvariable
  end

  # This method is here only until Core will be repaired (NULL_URI cannot be compared with other instance of an UESURI if the other
  # instance is not invariable).
  #
  # <tt><b>param</b></tt> first First compared UESURI.
  #
  # <tt><b>param</b></tt> second Second compared UESURI.
  #
  # <tt><b>return</b></tt> True, when both UESURI are the same, otherwise false.
  #
  # <tt><b>since</b></tt> UES6-04
  def self.isSame(first, second)
    uri1 = Java::cz.ues.core.commons.uri.UESURI.parseURI(first.to_s)
    uri2 = Java::cz.ues.core.commons.uri.UESURI.parseURI(second.to_s)
    return Java::cz.ues.core.commons.uri.UESURIHelper.isSame(uri1, uri2)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias is_same isSame
  end

  # Compares two UESURI according their territory and entity part. Both UESURI are the same as the corresponding
  # parts contains either the same Id or the same code. UESURI parts aren't comparable when one UESURIPart
  # contain only code and the other only Id. When incomparable UESURI parts are compared, exception is thrown.
  #
  # <tt><b>param</b></tt> first First compared UESURI.
  #
  # <tt><b>param</b></tt> second Second compared UESURI.
  #
  # <tt><b>return</b></tt> True, when both UESURI contains the same territory and entity parts, otherwise false.
  #
  # <tt><b>throws</b></tt> InsufficientUESURIRTException When UESURI contains some incomparable UESURIPart.
  #
  # <tt><b>since</b></tt> UES6-04
  def self.isSameEntity(first, second)
    uri1 = Java::cz.ues.core.commons.uri.UESURI.parseURI(first.to_s)
    uri2 = Java::cz.ues.core.commons.uri.UESURI.parseURI(second.to_s)
    return Java::cz.ues.core.commons.uri.UESURIHelper.isSameEntity(uri1, uri2)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias is_same_entity isSameEntity
  end

  # Build UES URI of territory from UES URI of any object.
  #
  # <tt><b>param</b></tt> objectUri UES URI of any object (code or id of territory must be set)
  #
  # <tt><b>return</b></tt> UES URI of object territory. UES URI is <b>not</b> normalized.
  #
  # <tt><b>since</b></tt> UES6-06
  def self.buildTerritoryUriFromAnyUri(objectUri)
    uri = Java::cz.ues.core.commons.uri.UESURI.parseURI(objectUri.to_s)
    res = Java::cz.ues.core.commons.uri.UESURIHelper.buildTerritoryUriFromAnyUri(uri)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias build_territory_uri_from_any_uri buildTerritoryUriFromAnyUri
  end

  # Build UES URI of aggregate object related to an artifact.
  #
  # <tt><b>param</b></tt> artifactUri UES URI of artifact
  #
  # <tt><b>param</b></tt> aggregateObjectCode code of aggregate object
  #
  # <tt><b>return</b></tt> UES URI of aggregate object. UES URI is <b>not</b> normalized.
  #
  # <tt><b>since</b></tt> UES6-06
  def self.buildObjectUriFromArtifactUri(artifactUri, aggregateObjectCode)
    uri = Java::cz.ues.core.commons.uri.UESURI.parseURI(artifactUri.to_s)
    res = Java::cz.ues.core.commons.uri.UESURIHelper.buildObjectUriFromArtifactUri(uri, aggregateObjectCode)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias build_object_uri_from_artifact_uri buildObjectUriFromArtifactUri
  end

  # Extracts the Artifact-URI from the passed UES-URI.
  # 
  # <tt><b>param</b></tt> agregatedObjectUri The URI of Artifact or Agregated object
  #
  # <tt><b>return</b></tt> The copy of the URI with purged Object URI-part
  #
  # <tt><b>since</b></tt> UES7-00
  def self.buildArtifactUriFromObjectUri(agregatedObjectUri)
    uri = Java::cz.ues.core.commons.uri.UESURI.parseURI(agregatedObjectUri.to_s)
    res = Java::cz.ues.core.commons.uri.UESURIHelper.buildArtifactUriFromObjectUri(uri)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias build_artifact_uri_from_object_uri buildArtifactUriFromObjectUri
  end

  # Creates copy of the specified UES URI.
  #
  # <tt><b>param</b></tt> uri UES URI of any object
  #
  # <tt><b>return</b></tt> Copy of UES URI as UESURIBuilder.
  #
  # <tt><b>since</b></tt> UES6-06
  def self.buildCopyOfUri(uri)
    uri1 = Java::cz.ues.core.commons.uri.UESURI.parseURI(uri.to_s)
    return Java::cz.ues.core.commons.uri.UESURIHelper.buildCopyOfUri(uri1)
  end
  class << Ues::Core::Commons::Uri::UESURIHelper
    alias build_copy_of_uri buildCopyOfUri
  end

end
