require 'pathname'
require 'fileutils'

# Tool for registration of Yubikeys.
#
# <tt><b>since</b></tt> UES7-06
class Ues::Platform::Security::Authn::UESYubikeyRegistrationTool
  private_class_method :new
  # Registers new Yubikey. After registration Yubikey can be activated
  # by user to be used for authentication. As parameters are accepted:
  # * Full path to output file of Yubikey configuration tool (either Personalization Tool or Multi-configuration tool)
  # * Values publicId, privateId and privateKey of registered token
  #
  # <tt><b>since</b></tt> UES7-06
  def self.registerYubikey(*params)
    if ((params == nil) || ((params.size != 1) && (params.size != 3)))
      raise "Given parameters cannot be used for Yubikey registration."
    end
    if (Java::cz.ues.platform.container.UESComponentFactory.containsComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class))
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class)
    else
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.wsc.WSCUESYubikeyRegistrationTool.java_class)
    end
    if (params.size == 3)
      _s.registerYubikey(params[0].strip, params[1].strip, params[2].strip)
    else
      File.open(params[0], 'r') do |file|
        file.read.each_line do |line|
          parts = line.strip.split(/,/)
          if ((parts.size == 18) && (parts[0].match(/^Yubico OTP/)))
            # output from Personalization Tool
            _s.registerYubikey(parts[3].strip, parts[4].strip, parts[5].strip)
          elsif (parts.size == 6)
            # output from Multi-configuration tool
            _s.registerYubikey(parts[1].strip, parts[2].strip, parts[3].strip)
          end
        end
      end
    end
  end
  class << Ues::Platform::Security::Authn::UESYubikeyRegistrationTool
    alias register_yubikey registerYubikey
  end

  # Checks if Yubikey is registered (it is known to system).
  #
  # <tt><b>param</b></tt> param One-time password generated by Yubikey, or full path to file containing multiple one-time passwords (one on each line)
  #
  # <tt><b>since</b></tt> UES7-06
  def self.isYubikeyRegistered(param)
    if (Java::cz.ues.platform.container.UESComponentFactory.containsComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class))
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class)
    else
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.wsc.WSCUESYubikeyRegistrationTool.java_class)
    end
    if (File.exists?(param))
      result = Hash.new
      File.open(param, 'r') do |file|
        file.read.each_line do |line|
          line.strip!
          if (!line.empty?)
            result[line] = _s.isYubikeyRegistered(line)
          end
        end
      end
      return result
    else
      return _s.isYubikeyRegistered(param)
    end
  end
  class << Ues::Platform::Security::Authn::UESYubikeyRegistrationTool
    alias is_yubikey_registered isYubikeyRegistered
  end

  # Checks if Yubikey is activated (was activated by some user).
  #
  # <tt><b>param</b></tt> param One-time password generated by Yubikey, or full path to file containing multiple one-time passwords (one on each line)
  #
  # <tt><b>since</b></tt> UES7-06
  def self.isYubikeyActivated(param)
    if (Java::cz.ues.platform.container.UESComponentFactory.containsComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class))
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.UESYubikeyRegistrationTool.java_class)
    else
      _s = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.platform.security.authn.yubikey.wsc.WSCUESYubikeyRegistrationTool.java_class)
    end
    if (File.exists?(param))
      result = Hash.new
      File.open(param, 'r') do |file|
        file.read.each_line do |line|
          line.strip!
          if (!line.empty?)
            result[line] = _s.isYubikeyActivated(line)
          end
        end
      end
      return result
    else
      return _s.isYubikeyActivated(param)
    end
  end
  class << Ues::Platform::Security::Authn::UESYubikeyRegistrationTool
    alias is_yubikey_activated isYubikeyActivated
  end

end
